@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from functools import wraps
 
 import numpy as np
@@ -76,7 +78,7 @@ def masked_where(condition, a):
     cshape = getattr(condition, "shape", ())
     if cshape and cshape != a.shape:
         raise IndexError(
-            "Inconsistant shape between the condition and the "
+            "Inconsistent shape between the condition and the "
             "input (got %s and %s)" % (cshape, a.shape)
         )
     condition = asanyarray(condition)
