@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import os
 import warnings
+from contextlib import nullcontext as does_not_warn
 from itertools import permutations, zip_longest
 
 import pytest
@@ -12,7 +13,7 @@ import itertools
 
 import dask.array as da
 import dask.config as config
-from dask.array.numpy_compat import _numpy_122
+from dask.array.numpy_compat import NUMPY_GE_122, ComplexWarning
 from dask.array.utils import assert_eq, same_keys
 from dask.core import get_deps
 
@@ -102,9 +103,10 @@ def reduction_1d_test(da_func, darr, np_func, narr, use_dtype=True, split_every=
     assert same_keys(da_func(darr), da_func(darr))
     assert same_keys(da_func(darr, keepdims=True), da_func(darr, keepdims=True))
     if use_dtype:
-        assert_eq(da_func(darr, dtype="f8"), np_func(narr, dtype="f8"))
-        assert_eq(da_func(darr, dtype="i8"), np_func(narr, dtype="i8"))
-        assert same_keys(da_func(darr, dtype="i8"), da_func(darr, dtype="i8"))
+        with pytest.warns(ComplexWarning) if np.iscomplexobj(narr) else does_not_warn():
+            assert_eq(da_func(darr, dtype="f8"), np_func(narr, dtype="f8"))
+            assert_eq(da_func(darr, dtype="i8"), np_func(narr, dtype="i8"))
+            assert same_keys(da_func(darr, dtype="i8"), da_func(darr, dtype="i8"))
     if split_every:
         a1 = da_func(darr, split_every=2)
         a2 = da_func(darr, split_every={0: 2})
@@ -116,10 +118,12 @@ def reduction_1d_test(da_func, darr, np_func, narr, use_dtype=True, split_every=
         )
 
 
-@pytest.mark.parametrize("dtype", ["f4", "i4"])
+@pytest.mark.parametrize("dtype", ["f4", "i4", "c8"])
 def test_reductions_1D(dtype):
-    x = np.arange(5).astype(dtype)
-    a = da.from_array(x, chunks=(2,))
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore", ComplexWarning)
+        x = (np.arange(5) + 1j * np.arange(5)).astype(dtype)
+        a = da.from_array(x, chunks=(2,))
 
     reduction_1d_test(da.sum, a, np.sum, x)
     reduction_1d_test(da.prod, a, np.prod, x)
@@ -161,8 +165,9 @@ def reduction_2d_test(da_func, darr, np_func, narr, use_dtype=True, split_every=
     assert same_keys(da_func(darr, axis=(1, 0)), da_func(darr, axis=(1, 0)))
 
     if use_dtype:
-        assert_eq(da_func(darr, dtype="f8"), np_func(narr, dtype="f8"))
-        assert_eq(da_func(darr, dtype="i8"), np_func(narr, dtype="i8"))
+        with pytest.warns(ComplexWarning) if np.iscomplexobj(narr) else does_not_warn():
+            assert_eq(da_func(darr, dtype="f8"), np_func(narr, dtype="f8"))
+            assert_eq(da_func(darr, dtype="i8"), np_func(narr, dtype="i8"))
 
     if split_every:
         a1 = da_func(darr, split_every=4)
@@ -200,9 +205,11 @@ def test_reduction_errors():
 
 
 @pytest.mark.slow
-@pytest.mark.parametrize("dtype", ["f4", "i4"])
+@pytest.mark.parametrize("dtype", ["f4", "i4", "c8"])
 def test_reductions_2D(dtype):
-    x = np.arange(1, 122).reshape((11, 11)).astype(dtype)
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore", ComplexWarning)
+        x = (np.arange(1, 122) + 1j * np.arange(1, 122)).reshape((11, 11)).astype(dtype)
     a = da.from_array(x, chunks=(4, 4))
 
     b = a.sum(keepdims=True)
@@ -254,7 +261,7 @@ def test_arg_reductions(dfunc, func):
         assert_eq(dfunc(a, 0), func(x, 0))
         assert_eq(dfunc(a, 1), func(x, 1))
         assert_eq(dfunc(a, 2), func(x, 2))
-    if _numpy_122:
+    if NUMPY_GE_122:
         assert_eq(dfunc(a, keepdims=True), func(x, keepdims=True))
 
     pytest.raises(ValueError, lambda: dfunc(a, 3))
