@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import os
 import uuid
 from fnmatch import fnmatch
@@ -18,7 +20,7 @@ from dask.base import (
 from dask.dataframe.backends import dataframe_creation_dispatch
 from dask.dataframe.core import DataFrame, Scalar
 from dask.dataframe.io.io import _link, from_map
-from dask.dataframe.io.utils import DataFrameIOFunction
+from dask.dataframe.io.utils import DataFrameIOFunction, SupportsLock
 from dask.highlevelgraph import HighLevelGraph
 from dask.utils import get_scheduler_lock
 
@@ -219,19 +221,28 @@ def to_hdf(
             lock = True
         else:
             lock = False
-    if lock:
+
+    # TODO: validation logic to ensure that provided locks are compatible with the scheduler
+    if isinstance(lock, bool) and lock:
         lock = get_scheduler_lock(df, scheduler=scheduler)
-
-    kwargs.update({"format": "table", "mode": mode, "append": append})
-
+    elif lock:
+        assert isinstance(lock, SupportsLock)
     dsk = dict()
 
     i_name = name_function(0)
+    kwargs.update(
+        {
+            "format": "table",
+            "mode": mode,
+            "append": append,
+            "key": key.replace("*", i_name),
+        }
+    )
     dsk[(name, 0)] = (
         _pd_to_hdf,
         pd_to_hdf,
         lock,
-        [(df._name, 0), fmt_obj(path, i_name), key.replace("*", i_name)],
+        [(df._name, 0), fmt_obj(path, i_name)],
         kwargs,
     )
 
@@ -248,12 +259,13 @@ def to_hdf(
 
     for i in range(1, df.npartitions):
         i_name = name_function(i)
+        kwargs2["key"] = key.replace("*", i_name)
         task = (
             _pd_to_hdf,
             pd_to_hdf,
             lock,
-            [(df._name, i), fmt_obj(path, i_name), key.replace("*", i_name)],
-            kwargs2,
+            [(df._name, i), fmt_obj(path, i_name)],
+            kwargs2.copy(),
         )
         if single_file:
             link_dep = i - 1 if single_node else 0
@@ -436,10 +448,10 @@ def read_hdf(
     # Build metadata
     with pd.HDFStore(paths[0], mode=mode) as hdf:
         meta_key = _expand_key(key, hdf)[0]
-    try:
-        meta = pd.read_hdf(paths[0], meta_key, mode=mode, stop=0)
-    except IndexError:  # if file is empty, don't set stop
-        meta = pd.read_hdf(paths[0], meta_key, mode=mode)
+        try:
+            meta = pd.read_hdf(hdf, meta_key, stop=0)
+        except IndexError:  # if file is empty, don't set stop
+            meta = pd.read_hdf(hdf, meta_key)
     if columns is not None:
         meta = meta[columns]
 
