@@ -11,7 +11,9 @@ import pytest
 pd = pytest.importorskip("pandas")
 dd = pytest.importorskip("dask.dataframe")
 
+import fsspec
 from fsspec.compression import compr
+from packaging.version import Version
 from tlz import partition_all, valmap
 
 import dask
@@ -19,7 +21,7 @@ from dask.base import compute_as_if_collection
 from dask.bytes.core import read_bytes
 from dask.bytes.utils import compress
 from dask.core import flatten
-from dask.dataframe._compat import PANDAS_GE_140, PANDAS_GE_200, tm
+from dask.dataframe._compat import PANDAS_GE_140, PANDAS_GE_200, PANDAS_GE_220, tm
 from dask.dataframe.io.csv import (
     _infer_block_size,
     auto_blocksize,
@@ -197,6 +199,7 @@ def test_pandas_read_text_with_header(reader, files):
     assert df.id.sum() == 1 + 2 + 3
 
 
+@pytest.mark.skipif(dd._dask_expr_enabled(), reason="not supported")
 @csv_and_table
 def test_text_blocks_to_pandas_simple(reader, files):
     blocks = [[files[k]] for k in sorted(files)]
@@ -638,7 +641,9 @@ def test_consistent_dtypes_2():
     with filetexts({"foo.1.csv": text1, "foo.2.csv": text2}):
         df = dd.read_csv("foo.*.csv", blocksize=25)
         assert df.name.dtype == string_dtype
-        assert df.name.compute().dtype == string_dtype
+        assert df.name.compute().dtype == (
+            string_dtype if not dd._dask_expr_enabled() else "object"
+        )
 
 
 def test_categorical_dtypes():
@@ -1102,7 +1107,7 @@ def test_assume_missing():
     with filetext(text) as fn:
         sol = pd.read_csv(fn)
 
-        # assume_missing ignored when all dtypes specifed
+        # assume_missing ignored when all dtypes specified
         df = dd.read_csv(fn, sample=30, dtype="int64", assume_missing=True)
         assert df.numbers.dtype == "int64"
 
@@ -1115,6 +1120,10 @@ def test_index_col():
         except ValueError as e:
             assert "set_index" in str(e)
 
+        df = pd.read_csv(fn, index_col=False)
+        ddf = dd.read_csv(fn, blocksize=30, index_col=False)
+        assert_eq(df, ddf, check_index=False)
+
 
 def test_read_csv_with_datetime_index_partitions_one():
     with filetext(timeseries) as fn:
@@ -1146,17 +1155,8 @@ def test_read_csv_with_datetime_index_partitions_n():
         assert_eq(df, ddf)
 
 
-xfail_pandas_100 = pytest.mark.xfail(reason="https://github.com/dask/dask/issues/5787")
-
-
-@pytest.mark.parametrize(
-    "encoding",
-    [
-        pytest.param("utf-16", marks=xfail_pandas_100),
-        pytest.param("utf-16-le", marks=xfail_pandas_100),
-        "utf-16-be",
-    ],
-)
+# utf-8-sig and utf-16 both start with a BOM.
+@pytest.mark.parametrize("encoding", ["utf-8-sig", "utf-16", "utf-16-le", "utf-16-be"])
 def test_encoding_gh601(encoding):
     ar = pd.Series(range(0, 100))
     br = ar % 7
@@ -1210,12 +1210,21 @@ def test_parse_dates_multi_column():
     """
     )
 
-    with filetext(pdmc_text) as fn:
-        ddf = dd.read_csv(fn, parse_dates=[["date", "time"]])
-        df = pd.read_csv(fn, parse_dates=[["date", "time"]])
+    if PANDAS_GE_220:
+        with pytest.warns(FutureWarning, match="nested"):
+            with filetext(pdmc_text) as fn:
+                ddf = dd.read_csv(fn, parse_dates=[["date", "time"]])
+                df = pd.read_csv(fn, parse_dates=[["date", "time"]])
 
-        assert (df.columns == ddf.columns).all()
-        assert len(df) == len(ddf)
+                assert (df.columns == ddf.columns).all()
+                assert len(df) == len(ddf)
+    else:
+        with filetext(pdmc_text) as fn:
+            ddf = dd.read_csv(fn, parse_dates=[["date", "time"]])
+            df = pd.read_csv(fn, parse_dates=[["date", "time"]])
+
+            assert (df.columns == ddf.columns).all()
+            assert len(df) == len(ddf)
 
 
 def test_read_csv_sep():
@@ -1475,6 +1484,30 @@ def test_to_single_csv_with_header_first_partition_only():
             )
 
 
+def test_to_csv_with_single_file_and_exclusive_mode():
+    df0 = pd.DataFrame({"x": ["a", "b", "c", "d"], "y": [1, 2, 3, 4]})
+    df = dd.from_pandas(df0, npartitions=2)
+    with tmpdir() as directory:
+        csv_path = os.path.join(directory, "test.csv")
+        df.to_csv(csv_path, index=False, mode="x", single_file=True)
+        result = dd.read_csv(os.path.join(directory, "*")).compute()
+    assert_eq(result, df0, check_index=False)
+
+
+def test_to_csv_single_file_exlusive_mode_no_overwrite():
+    df0 = pd.DataFrame({"x": ["a", "b", "c", "d"], "y": [1, 2, 3, 4]})
+    df = dd.from_pandas(df0, npartitions=2)
+    with tmpdir() as directory:
+        csv_path = os.path.join(str(directory), "test.csv")
+        df.to_csv(csv_path, index=False, mode="x", single_file=True)
+        assert os.path.exists(csv_path)
+        # mode="x" should fail if file already exists
+        with pytest.raises(FileExistsError):
+            df.to_csv(csv_path, index=False, mode="x", single_file=True)
+        # but mode="w" will overwrite an existing file
+        df.to_csv(csv_path, index=False, mode="w", single_file=True)
+
+
 def test_to_single_csv_gzip():
     df = pd.DataFrame({"x": ["a", "b", "c", "d"], "y": [1, 2, 3, 4]})
 
@@ -1501,6 +1534,10 @@ def test_to_csv_gzip():
             tm.assert_frame_equal(result, df)
 
 
+@pytest.mark.skipif(
+    Version(fsspec.__version__) == Version("2023.9.1"),
+    reason="https://github.com/dask/dask/issues/10515",
+)
 def test_to_csv_nodir():
     # See #6062 https://github.com/intake/filesystem_spec/pull/271 and
     df0 = pd.DataFrame(
@@ -1529,6 +1566,33 @@ def test_to_csv_simple():
     assert (result.x.values == df0.x.values).all()
 
 
+def test_to_csv_with_single_file_and_append_mode():
+    # regression test for https://github.com/dask/dask/issues/10414
+    df0 = pd.DataFrame(
+        {"x": ["a", "b"], "y": [1, 2]},
+    )
+    df1 = pd.DataFrame(
+        {"x": ["c", "d"], "y": [3, 4]},
+    )
+    df = dd.from_pandas(df1, npartitions=2)
+    with tmpdir() as dir:
+        csv_path = os.path.join(dir, "test.csv")
+        df0.to_csv(
+            csv_path,
+            index=False,
+        )
+        df.to_csv(
+            csv_path,
+            mode="a",
+            header=False,
+            index=False,
+            single_file=True,
+        )
+        result = dd.read_csv(os.path.join(dir, "*")).compute()
+    expected = pd.concat([df0, df1])
+    assert assert_eq(result, expected, check_index=False)
+
+
 def test_to_csv_series():
     df0 = pd.Series(["a", "b", "c", "d"], index=[1.0, 2.0, 3.0, 4.0])
     df = dd.from_pandas(df0, npartitions=2)
