@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import glob
 import os
 import shutil
@@ -59,13 +61,14 @@ def test_orc_single(orc_files, split_stripes):
     with pytest.raises(ValueError, match="nonexist"):
         dd.read_orc(fn, columns=["time", "nonexist"])
 
-    # Check that `optimize_dataframe_getitem` changes the
-    # `columns` attribute of the "read-orc" layer
-    d3 = d[columns]
-    keys = [(d3._name, i) for i in range(d3.npartitions)]
-    graph = optimize_dataframe_getitem(d3.__dask_graph__(), keys)
-    key = [k for k in graph.layers.keys() if k.startswith("read-orc-")][0]
-    assert set(graph.layers[key].columns) == set(columns)
+    if not dd._dask_expr_enabled():
+        # Check that `optimize_dataframe_getitem` changes the
+        # `columns` attribute of the "read-orc" layer
+        d3 = d[columns]
+        keys = [(d3._name, i) for i in range(d3.npartitions)]
+        graph = optimize_dataframe_getitem(d3.__dask_graph__(), keys)
+        key = [k for k in graph.layers.keys() if k.startswith("read-orc-")][0]
+        assert set(graph.layers[key].columns) == set(columns)
 
 
 @pytest.mark.network
