@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import contextlib
 
 import numpy as np
@@ -5,7 +7,7 @@ import pytest
 
 pd = pytest.importorskip("pandas")
 import dask.dataframe as dd
-from dask.dataframe._compat import PANDAS_GT_140, PANDAS_GT_210
+from dask.dataframe._compat import PANDAS_GE_140, PANDAS_GE_210, PANDAS_GE_300
 from dask.dataframe._pyarrow import to_pyarrow_string
 from dask.dataframe.utils import assert_eq, pyarrow_strings_enabled
 
@@ -46,6 +48,8 @@ class MyAccessor:
     ],
 )
 def test_register(obj, registrar):
+    if dd._dask_expr_enabled() and obj is dd.Index:
+        pytest.skip("from_pandas doesn't support Index")
     with ensure_removed(obj, "mine"):
         before = set(dir(obj))
         registrar("mine")(MyAccessor)
@@ -91,6 +95,9 @@ def df_ddf():
     return df, ddf
 
 
+@pytest.mark.skipif(
+    not PANDAS_GE_210 or PANDAS_GE_300, reason="warning is None|divisions are incorrect"
+)
 def test_dt_accessor(df_ddf):
     df, ddf = df_ddf
 
@@ -99,20 +106,25 @@ def test_dt_accessor(df_ddf):
     # pandas loses Series.name via datetime accessor
     # see https://github.com/pydata/pandas/issues/10712
     assert_eq(ddf.dt_col.dt.date, df.dt_col.dt.date, check_names=False)
-
-    warning = FutureWarning if PANDAS_GT_210 else None
+    warning_ctx = pytest.warns(FutureWarning, match="will return a Series")
     # to_pydatetime returns a numpy array in pandas, but a Series in dask
     # pandas will start returning a Series with 3.0 as well
-    with pytest.warns(warning, match="will return a Series"):
+    with warning_ctx:
         ddf_result = ddf.dt_col.dt.to_pydatetime()
-    with pytest.warns(warning, match="will return a Series"):
+    with warning_ctx:
         pd_result = pd.Series(
             df.dt_col.dt.to_pydatetime(), index=df.index, dtype=object
         )
     assert_eq(ddf_result, pd_result)
 
     assert set(ddf.dt_col.dt.date.dask) == set(ddf.dt_col.dt.date.dask)
-    with pytest.warns(warning, match="will return a Series"):
+    if dd._dask_expr_enabled():
+        # The warnings is raised during construction of the expression, not the
+        # materialization of the graph. Therefore, the singleton approach of
+        # dask-expr avoids another warning
+        ctx = contextlib.nullcontext()
+
+    with ctx:
         assert set(ddf.dt_col.dt.to_pydatetime().dask) == set(
             ddf.dt_col.dt.to_pydatetime().dask
         )
@@ -156,9 +168,10 @@ def test_str_accessor(df_ddf):
     ctx = contextlib.nullcontext()
     if pyarrow_strings_enabled():
         df.str_col = to_pyarrow_string(df.str_col)
-        ctx = pytest.warns(
-            pd.errors.PerformanceWarning, match="Falling back on a non-pyarrow"
-        )
+        if not PANDAS_GE_210:
+            ctx = pytest.warns(
+                pd.errors.PerformanceWarning, match="Falling back on a non-pyarrow"
+            )
     assert_eq(
         ddf.str_col.str.contains("a"),
         df.str_col.str.contains("a"),
@@ -221,7 +234,7 @@ def test_str_accessor_extractall(df_ddf):
     )
 
 
-@pytest.mark.skipif(not PANDAS_GT_140, reason="requires pandas >= 1.4.0")
+@pytest.mark.skipif(not PANDAS_GE_140, reason="requires pandas >= 1.4.0")
 @pytest.mark.parametrize("method", ["removeprefix", "removesuffix"])
 def test_str_accessor_removeprefix_removesuffix(df_ddf, method):
     df, ddf = df_ddf
@@ -313,7 +326,10 @@ def test_str_accessor_split_expand_more_columns():
     s = pd.Series(["a b c", "aa bb cc", "aaa bbb ccc"])
     ds = dd.from_pandas(s, npartitions=2)
 
-    ds.str.split(n=10, expand=True).compute()
+    assert_eq(
+        ds.str.split(n=10, expand=True),
+        s.str.split(n=10, expand=True),
+    )
 
 
 @pytest.mark.parametrize("index", [None, [0]], ids=["range_index", "other index"])
