@@ -1,14 +1,17 @@
+from __future__ import annotations
+
 import re
 import warnings
-from typing import Iterable
+from collections.abc import Iterable
 
 import numpy as np
 import pandas as pd
 import pytest
+from packaging.version import Version
 
 import dask
 import dask.dataframe as dd
-from dask.dataframe._compat import PANDAS_GT_200, tm
+from dask.dataframe._compat import PANDAS_GE_200, PANDAS_GE_300, tm
 from dask.dataframe.core import apply_and_enforce
 from dask.dataframe.utils import (
     UNKNOWN_CATEGORIES,
@@ -22,6 +25,7 @@ from dask.dataframe.utils import (
     meta_frame_constructor,
     meta_nonempty,
     meta_series_constructor,
+    pyarrow_strings_enabled,
     raise_on_meta_error,
     shard_df_on_index,
     valid_divisions,
@@ -269,7 +273,7 @@ def test_meta_nonempty_index():
     idx = pd.Index([1], name="foo", dtype="int")
     res = meta_nonempty(idx)
     assert type(res) is type(idx)
-    if PANDAS_GT_200:
+    if PANDAS_GE_200:
         assert res.dtype == np.int_
     else:
         # before pandas 2.0, index dtypes were only x64
@@ -427,11 +431,12 @@ def test_check_meta():
     df2 = df[["a", "b", "d", "e"]]
     with pytest.raises(ValueError) as err:
         check_meta(df2, meta2, funcname="from_delayed")
+    frame = "pandas.core.frame.DataFrame" if not PANDAS_GE_300 else "pandas.DataFrame"
 
     exp = (
         "Metadata mismatch found in `from_delayed`.\n"
         "\n"
-        "Partition type: `pandas.core.frame.DataFrame`\n"
+        f"Partition type: `{frame}`\n"
         "+--------+----------+----------+\n"
         "| Column | Found    | Expected |\n"
         "+--------+----------+----------+\n"
@@ -520,7 +525,7 @@ def test_is_dataframe_like(monkeypatch, frame_value_counts):
     assert not is_index_like(pd.Index)
 
     # The following checks support of class wrappers, which
-    # requires the comparions of `x.__class__` instead of `type(x)`
+    # requires the comparisons of `x.__class__` instead of `type(x)`
     class DataFrameWrapper:
         __class__ = pd.DataFrame
 
@@ -669,3 +674,28 @@ def test_meta_constructor_utilities_raise(data):
 )
 def test_valid_divisions(divisions, valid):
     assert valid_divisions(divisions) == valid
+
+
+def test_pyarrow_strings_enabled():
+    try:
+        import pyarrow as pa
+    except ImportError:
+        pa = None
+
+    # If `pandas>=2` and `pyarrow>=12` are installed, then default to using pyarrow strings
+    if (
+        PANDAS_GE_200
+        and pa is not None
+        and Version(pa.__version__) >= Version("12.0.0")
+    ):
+        assert pyarrow_strings_enabled() is True
+    else:
+        assert pyarrow_strings_enabled() is False
+
+    # Regardless of dependencies that are installed, always obey
+    # the `dataframe.convert-string` config value if it's specified
+    with dask.config.set({"dataframe.convert-string": False}):
+        assert pyarrow_strings_enabled() is False
+
+    with dask.config.set({"dataframe.convert-string": True}):
+        assert pyarrow_strings_enabled() is True
