@@ -1,9 +1,12 @@
+from __future__ import annotations
+
 from itertools import product
 
 import pandas as pd
 import pytest
 
 import dask.dataframe as dd
+from dask.dataframe._compat import PANDAS_GE_220
 from dask.dataframe.utils import assert_eq
 
 
@@ -11,6 +14,9 @@ def resample(df, freq, how="mean", **kwargs):
     return getattr(df.resample(freq, **kwargs), how)()
 
 
+ME = "ME" if PANDAS_GE_220 else "M"
+
+
 @pytest.mark.parametrize(
     ["obj", "method", "npartitions", "freq", "closed", "label"],
     list(
@@ -18,7 +24,7 @@ def resample(df, freq, how="mean", **kwargs):
             ["series", "frame"],
             ["count", "mean", "ohlc"],
             [2, 5],
-            ["30T", "h", "d", "w", "M"],
+            ["30min", "h", "D", "W", ME],
             ["right", "left"],
             ["right", "left"],
         )
@@ -87,7 +93,7 @@ def test_resample_throws_error_when_parition_index_does_not_match_index():
     ps = pd.Series(range(len(index)), index=index)
     ds = dd.from_pandas(ps, npartitions=5)
     with pytest.raises(ValueError, match="Index is not contained within new index."):
-        ds.resample("2M").count().compute()
+        ds.resample(f"2{ME}").count().compute()
 
 
 def test_resample_pads_last_division_to_avoid_off_by_one():
@@ -118,20 +124,21 @@ def test_resample_pads_last_division_to_avoid_off_by_one():
         1559127673402811000,
     ]
 
+    freq = "1QE" if PANDAS_GE_220 else "1Q"
     df = pd.DataFrame({"Time": times, "Counts": range(len(times))})
     df["Time"] = pd.to_datetime(df["Time"], utc=True)
-    expected = df.set_index("Time").resample("1Q").size()
+    expected = df.set_index("Time").resample(freq).size()
 
     ddf = dd.from_pandas(df, npartitions=2).set_index("Time")
-    actual = ddf.resample("1Q").size().compute()
+    actual = ddf.resample(freq).size().compute()
     assert_eq(actual, expected)
 
 
 def test_resample_does_not_evenly_divide_day():
     import numpy as np
 
-    index = pd.date_range("2012-01-02", "2012-02-02", freq="H")
-    index = index.union(pd.date_range("2012-03-02", "2012-04-02", freq="H"))
+    index = pd.date_range("2012-01-02", "2012-02-02", freq="h")
+    index = index.union(pd.date_range("2012-03-02", "2012-04-02", freq="h"))
     df = pd.DataFrame({"p": np.random.random(len(index))}, index=index)
     ddf = dd.from_pandas(df, npartitions=5)
     # Frequency doesn't evenly divide day
@@ -142,22 +149,22 @@ def test_resample_does_not_evenly_divide_day():
 
 
 def test_series_resample_does_not_evenly_divide_day():
-    index = pd.date_range("2012-01-02 00:00:00", "2012-01-02 01:00:00", freq="T")
+    index = pd.date_range("2012-01-02 00:00:00", "2012-01-02 01:00:00", freq="min")
     index = index.union(
-        pd.date_range("2012-01-02 06:00:00", "2012-01-02 08:00:00", freq="T")
+        pd.date_range("2012-01-02 06:00:00", "2012-01-02 08:00:00", freq="min")
     )
     s = pd.Series(range(len(index)), index=index)
     ds = dd.from_pandas(s, npartitions=5)
     # Frequency doesn't evenly divide day
-    expected = s.resample("57T").mean()
-    result = ds.resample("57T").mean().compute()
+    expected = s.resample("57min").mean()
+    result = ds.resample("57min").mean().compute()
 
     assert_eq(result, expected)
 
 
 def test_unknown_divisions_error():
     df = pd.DataFrame({"x": [1, 2, 3]})
-    ddf = dd.from_pandas(df, npartitions=2, sort=False)
+    ddf = dd.from_pandas(df, npartitions=2, sort=False).clear_divisions()
     try:
         ddf.x.resample("1m").mean()
         assert False
