@@ -1,21 +1,22 @@
+from __future__ import annotations
+
 from operator import add, mul
 
 import pytest
 
 from dask.callbacks import Callback
-from dask.local import get_sync
 from dask.diagnostics import ProgressBar
 from dask.diagnostics.progress import format_time
+from dask.local import get_sync
 from dask.threaded import get as get_threaded
 
-
 dsk = {"a": 1, "b": 2, "c": (add, "a", "b"), "d": (mul, "a", "b"), "e": (mul, "c", "d")}
 
 
 def check_bar_completed(capsys, width=40):
     out, err = capsys.readouterr()
     assert out.count("100% Completed") == 1
-    bar, percent, time = [i.strip() for i in out.split("\r")[-1].split("|")]
+    bar, percent, time = (i.strip() for i in out.split("\r")[-1].split("|"))
     assert bar == "[" + "#" * width + "]"
     assert percent == "100% Completed"
 
@@ -41,7 +42,7 @@ def test_progressbar(capsys):
 
 
 def test_minimum_time(capsys):
-    with ProgressBar(1.0):
+    with ProgressBar(10.0):
         out = get_threaded(dsk, "e")
     out, err = capsys.readouterr()
     assert out == "" and err == ""
@@ -60,15 +61,19 @@ def test_clean_exit(get):
 
 
 def test_format_time():
-    assert format_time(1.4) == " 1.4s"
-    assert format_time(10.4) == "10.4s"
-    assert format_time(100.4) == " 1min 40.4s"
-    assert format_time(1000.4) == "16min 40.4s"
-    assert format_time(10000.4) == " 2hr 46min 40.4s"
+    with pytest.warns(FutureWarning, match="dask.utils.format_time") as record:
+        assert format_time(1.4) == " 1.4s"
+        assert format_time(10.4) == "10.4s"
+        assert format_time(100.4) == " 1min 40.4s"
+        assert format_time(1000.4) == "16min 40.4s"
+        assert format_time(10000.4) == " 2hr 46min 40.4s"
+
+    assert len(record) == 5  # Each `assert` above warns
 
 
 def test_register(capsys):
     try:
+        assert not Callback.active
         p = ProgressBar()
         p.register()
 
